aboutsummaryrefslogtreecommitdiff
path: root/p
diff options
context:
space:
mode:
Diffstat (limited to 'p')
-rw-r--r--p/.htaccess9
-rw-r--r--p/api/greader.php51
-rw-r--r--p/api/index.php2
-rw-r--r--p/api/pshb.php42
-rw-r--r--p/ext.php2
-rw-r--r--p/f.php2
-rwxr-xr-xp/i/index.php2
-rw-r--r--p/scripts/main.js11
-rw-r--r--p/themes/BlueLagoon/BlueLagoon.css6
-rw-r--r--p/themes/Dark/dark.css6
-rw-r--r--p/themes/Flat/flat.css6
-rw-r--r--p/themes/Origine/origine.css6
-rw-r--r--p/themes/Pafat/pafat.css8
-rw-r--r--p/themes/Screwdriver/screwdriver.css6
-rw-r--r--p/themes/base-theme/base.css6
-rw-r--r--p/themes/base-theme/template.css10
-rw-r--r--p/themes/fonts/OpenSans.woffbin0 -> 67528 bytes
-rw-r--r--p/themes/fonts/OpenSans.woff2bin0 -> 61980 bytes
-rw-r--r--p/themes/fonts/openSans.woffbin21956 -> 0 bytes
19 files changed, 66 insertions, 109 deletions
diff --git a/p/.htaccess b/p/.htaccess
index 4321c82d7..74ba7ed11 100644
--- a/p/.htaccess
+++ b/p/.htaccess
@@ -6,6 +6,11 @@ FileETag None
AddDefaultCharset UTF-8
<IfModule mod_mime.c>
+ AddType application/json .map
+ AddType application/font-woff .woff
+ AddType application/font-woff2 .woff2
+
+ AddCharset UTF-8 .css
AddCharset UTF-8 .html
AddCharset UTF-8 .js
</IfModule>
@@ -16,6 +21,8 @@ AddDefaultCharset UTF-8
<IfModule mod_expires.c>
ExpiresActive on
+ ExpiresByType application/font-woff "access plus 1 month"
+ ExpiresByType application/font-woff2 "access plus 1 month"
ExpiresByType application/javascript "access plus 1 month"
ExpiresByType application/xhtml+xml "access plus 1 month"
ExpiresByType image/x-icon "access plus 1 month"
@@ -27,7 +34,7 @@ AddDefaultCharset UTF-8
</IfModule>
<IfModule mod_headers.c>
- <FilesMatch "\.(css|gif|html|ico|js|png|svg|woff)$">
+ <FilesMatch "\.(css|gif|html|ico|js|png|svg|woff|woff2)$">
Header merge Cache-Control "public"
</FilesMatch>
</IfModule>
diff --git a/p/api/index.php b/p/api/index.php
index 08f7b6b7b..429b25225 100644
--- a/p/api/index.php
+++ b/p/api/index.php
@@ -14,7 +14,7 @@
<dl>
<dt>Your API address:</dt>
<dd><?php
-require('../../constants.php');
+require(__DIR__ . '/../../constants.php');
require(LIB_PATH . '/lib_rss.php'); //Includes class autoloader
Minz_Configuration::register('system', DATA_PATH . '/config.php', FRESHRSS_PATH . '/config.default.php');
echo Minz_Url::display('/api/greader.php', 'html', true);
diff --git a/p/api/pshb.php b/p/api/pshb.php
index ed8326cf5..57a7bb0dd 100644
--- a/p/api/pshb.php
+++ b/p/api/pshb.php
@@ -1,19 +1,19 @@
<?php
-require('../../constants.php');
+require(__DIR__ . '/../../constants.php');
require(LIB_PATH . '/lib_rss.php'); //Includes class autoloader
-define('MAX_PAYLOAD', 3145728);
+const MAX_PAYLOAD = 3145728;
header('Content-Type: text/plain; charset=UTF-8');
header('X-Content-Type-Options: nosniff');
-function logMe($text) {
- file_put_contents(USERS_PATH . '/_/log_pshb.txt', date('c') . "\t" . $text . "\n", FILE_APPEND);
-}
-
$ORIGINAL_INPUT = file_get_contents('php://input', false, null, 0, MAX_PAYLOAD);
-//logMe(print_r(array('_SERVER' => $_SERVER, '_GET' => $_GET, '_POST' => $_POST, 'INPUT' => $ORIGINAL_INPUT), true));
+Minz_Configuration::register('system', DATA_PATH . '/config.php', FRESHRSS_PATH . '/config.default.php');
+$system_conf = Minz_Configuration::get('system');
+$system_conf->auth_type = 'none'; // avoid necessity to be logged in (not saved!)
+
+//Minz_Log::debug(print_r(array('_SERVER' => $_SERVER, '_GET' => $_GET, '_POST' => $_POST, 'INPUT' => $ORIGINAL_INPUT), true), PSHB_LOG);
$key = isset($_GET['k']) ? substr($_GET['k'], 0, 128) : '';
if (!ctype_xdigit($key)) {
@@ -24,31 +24,31 @@ chdir(PSHB_PATH);
$canonical64 = @file_get_contents('keys/' . $key . '.txt');
if ($canonical64 === false) {
if (!empty($_REQUEST['hub_mode']) && $_REQUEST['hub_mode'] === 'unsubscribe') {
- logMe('Warning: Accept unknown unsubscribe');
+ Minz_Log::warning('Warning: Accept unknown unsubscribe', PSHB_LOG);
header('Connection: close');
exit(isset($_REQUEST['hub_challenge']) ? $_REQUEST['hub_challenge'] : '');
}
header('HTTP/1.1 404 Not Found');
- logMe('Warning: Feed key not found!: ' . $key);
+ Minz_Log::warning('Warning: Feed key not found!: ' . $key, PSHB_LOG);
die('Feed key not found!');
}
$canonical64 = trim($canonical64);
if (!preg_match('/^[A-Za-z0-9_-]+$/D', $canonical64)) {
header('HTTP/1.1 500 Internal Server Error');
- logMe('Error: Invalid key reference!: ' . $canonical64);
+ Minz_Log::error('Error: Invalid key reference!: ' . $canonical64, PSHB_LOG);
die('Invalid key reference!');
}
$hubFile = @file_get_contents('feeds/' . $canonical64 . '/!hub.json');
if ($hubFile === false) {
header('HTTP/1.1 404 Not Found');
unlink('keys/' . $key . '.txt');
- logMe('Error: Feed info not found!: ' . $canonical64);
+ Minz_Log::error('Error: Feed info not found!: ' . $canonical64, PSHB_LOG);
die('Feed info not found!');
}
$hubJson = json_decode($hubFile, true);
if (!$hubJson || empty($hubJson['key']) || $hubJson['key'] !== $key) {
header('HTTP/1.1 500 Internal Server Error');
- logMe('Error: Invalid key cross-check!: ' . $key);
+ Minz_Log::error('Error: Invalid key cross-check!: ' . $key, PSHB_LOG);
die('Invalid key cross-check!');
}
chdir('feeds/' . $canonical64);
@@ -56,7 +56,7 @@ $users = glob('*.txt', GLOB_NOSORT);
if (empty($users)) {
header('HTTP/1.1 410 Gone');
$url = base64url_decode($canonical64);
- logMe('Warning: Nobody subscribes to this feed anymore!: ' . $url);
+ Minz_Log::warning('Warning: Nobody subscribes to this feed anymore!: ' . $url, PSHB_LOG);
unlink('../../keys/' . $key . '.txt');
Minz_Configuration::register('system',
DATA_PATH . '/config.php',
@@ -101,10 +101,6 @@ if ($ORIGINAL_INPUT == '') {
die('Missing XML payload!');
}
-Minz_Configuration::register('system', DATA_PATH . '/config.php', FRESHRSS_PATH . '/config.default.php');
-$system_conf = Minz_Configuration::get('system');
-$system_conf->auth_type = 'none'; // avoid necessity to be logged in (not saved!)
-
$simplePie = customSimplePie();
$simplePie->set_raw_data($ORIGINAL_INPUT);
$simplePie->init();
@@ -115,7 +111,7 @@ $self = isset($links[0]) ? $links[0] : null;
if ($self !== base64url_decode($canonical64)) {
//header('HTTP/1.1 422 Unprocessable Entity');
- logMe('Warning: Self URL [' . $self . '] does not match registered canonical URL!: ' . base64url_decode($canonical64));
+ Minz_Log::warning('Warning: Self URL [' . $self . '] does not match registered canonical URL!: ' . base64url_decode($canonical64), PSHB_LOG);
//die('Self URL does not match registered canonical URL!');
$self = base64url_decode($canonical64);
}
@@ -124,7 +120,7 @@ $nb = 0;
foreach ($users as $userFilename) {
$username = basename($userFilename, '.txt');
if (!file_exists(USERS_PATH . '/' . $username . '/config.php')) {
- logMe('Warning: Removing broken user link: ' . $username . ' for ' . $self);
+ Minz_Log::warning('Warning: Removing broken user link: ' . $username . ' for ' . $self, PSHB_LOG);
unlink($userFilename);
continue;
}
@@ -140,11 +136,11 @@ foreach ($users as $userFilename) {
if ($updated_feeds > 0 || $feed != false) {
$nb++;
} else {
- logMe('Warning: User ' . $username . ' does not subscribe anymore to ' . $self);
+ Minz_Log::warning('Warning: User ' . $username . ' does not subscribe anymore to ' . $self, PSHB_LOG);
unlink($userFilename);
}
} catch (Exception $e) {
- logMe('Error: ' . $e->getMessage() . ' for user ' . $username . ' and feed ' . $self);
+ Minz_Log::error('Error: ' . $e->getMessage() . ' for user ' . $username . ' and feed ' . $self, PSHB_LOG);
}
}
@@ -153,12 +149,12 @@ unset($simplePie);
if ($nb === 0) {
header('HTTP/1.1 410 Gone');
- logMe('Warning: Nobody subscribes to this feed anymore after all!: ' . $self);
+ Minz_Log::warning('Warning: Nobody subscribes to this feed anymore after all!: ' . $self, PSHB_LOG);
die('Nobody subscribes to this feed anymore after all!');
} elseif (!empty($hubJson['error'])) {
$hubJson['error'] = false;
file_put_contents('./!hub.json', json_encode($hubJson));
}
-logMe('PubSubHubbub ' . $self . ' done: ' . $nb);
+Minz_Log::notice('PubSubHubbub ' . $self . ' done: ' . $nb, PSHB_LOG);
exit('Done: ' . $nb . "\n");
diff --git a/p/ext.php b/p/ext.php
index 5c9f9125f..bb16d02d3 100644
--- a/p/ext.php
+++ b/p/ext.php
@@ -5,7 +5,7 @@ if (!isset($_GET['f']) ||
die();
}
-require('../constants.php');
+require(__DIR__ . '/../constants.php');
/**
* Check if a file can be served by ext.php. A valid file is under a
diff --git a/p/f.php b/p/f.php
index c47fa747a..81df8984b 100644
--- a/p/f.php
+++ b/p/f.php
@@ -1,5 +1,5 @@
<?php
-require('../constants.php');
+require(__DIR__ . '/../constants.php');
require(LIB_PATH . '/lib_rss.php'); //Includes class autoloader
require(LIB_PATH . '/favicons.php');
require(LIB_PATH . '/http-conditional.php');
diff --git a/p/i/index.php b/p/i/index.php
index d3fc0b37c..a1212b570 100755
--- a/p/i/index.php
+++ b/p/i/index.php
@@ -18,7 +18,7 @@
#
# ***** END LICENSE BLOCK *****
-require('../../constants.php');
+require(__DIR__ . '/../../constants.php');
require(LIB_PATH . '/lib_rss.php'); //Includes class autoloader
if (file_exists(DATA_PATH . '/do-install.txt')) {
diff --git a/p/scripts/main.js b/p/scripts/main.js
index 278ecfee9..ce8070008 100644
--- a/p/scripts/main.js
+++ b/p/scripts/main.js
@@ -1172,6 +1172,14 @@ function init_print_action() {
});
}
+function init_post_action() {
+ $('.item.share > a[href="POST"]').click(function (event) {
+ event.preventDefault();
+ var form = $(this).next('form');
+ $.post(form.data('url'), form.serialize());
+ });
+}
+
function init_share_observers() {
shares = $('.group-share').length;
@@ -1182,6 +1190,8 @@ function init_share_observers() {
row = row.replace(/##type##/g, opt.val());
row = row.replace(/##help##/g, opt.data('help'));
row = row.replace(/##key##/g, shares);
+ row = row.replace(/##method##/g, opt.data('method'));
+ row = row.replace(/##field##/g, opt.data('field'));
$(this).parents('.form-group').before(row);
shares++;
@@ -1398,6 +1408,7 @@ function init_afterDOM() {
init_posts();
init_nav_entries();
init_print_action();
+ init_post_action();
init_notifs_html5();
window.setInterval(refreshUnreads, 120000);
} else {
diff --git a/p/themes/BlueLagoon/BlueLagoon.css b/p/themes/BlueLagoon/BlueLagoon.css
index 150e27908..186258752 100644
--- a/p/themes/BlueLagoon/BlueLagoon.css
+++ b/p/themes/BlueLagoon/BlueLagoon.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/Dark/dark.css b/p/themes/Dark/dark.css
index d8415ef25..348b00009 100644
--- a/p/themes/Dark/dark.css
+++ b/p/themes/Dark/dark.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/Flat/flat.css b/p/themes/Flat/flat.css
index 0240fe4b4..62c4808a4 100644
--- a/p/themes/Flat/flat.css
+++ b/p/themes/Flat/flat.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/Origine/origine.css b/p/themes/Origine/origine.css
index becf3f433..4a697e811 100644
--- a/p/themes/Origine/origine.css
+++ b/p/themes/Origine/origine.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/Pafat/pafat.css b/p/themes/Pafat/pafat.css
index 23bc6671d..1b6ebca29 100644
--- a/p/themes/Pafat/pafat.css
+++ b/p/themes/Pafat/pafat.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
@@ -1069,4 +1063,4 @@ a.btn {
.notification a.close .icon {
display: none;
}
-} \ No newline at end of file
+}
diff --git a/p/themes/Screwdriver/screwdriver.css b/p/themes/Screwdriver/screwdriver.css
index b2c539b13..969695f13 100644
--- a/p/themes/Screwdriver/screwdriver.css
+++ b/p/themes/Screwdriver/screwdriver.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/base-theme/base.css b/p/themes/base-theme/base.css
index 1bf73d8b3..e265cd7ff 100644
--- a/p/themes/base-theme/base.css
+++ b/p/themes/base-theme/base.css
@@ -1,11 +1,5 @@
@charset "UTF-8";
-/*=== FONTS */
-@font-face {
- font-family: "OpenSans";
- src: url("../fonts/openSans.woff") format("woff");
-}
-
/*=== GENERAL */
/*============*/
html, body {
diff --git a/p/themes/base-theme/template.css b/p/themes/base-theme/template.css
index 320ad2d9b..e5e1bca05 100644
--- a/p/themes/base-theme/template.css
+++ b/p/themes/base-theme/template.css
@@ -2,9 +2,19 @@
/*=== GENERAL */
/*============*/
+@font-face {
+ font-family: 'OpenSans';
+ font-style: normal;
+ font-weight: 400;
+ src: local('Open Sans'), local('OpenSans'),
+ url('../fonts/OpenSans.woff2') format('woff2'),
+ url('../fonts/OpenSans.woff') format('woff');
+}
+
html, body {
margin: 0;
padding: 0;
+ font-family: "OpenSans", "Cantarell", "Helvetica", "Arial", sans-serif;
font-size: 100%;
}
diff --git a/p/themes/fonts/OpenSans.woff b/p/themes/fonts/OpenSans.woff
new file mode 100644
index 000000000..9a96e3baf
--- /dev/null
+++ b/p/themes/fonts/OpenSans.woff
Binary files differ
diff --git a/p/themes/fonts/OpenSans.woff2 b/p/themes/fonts/OpenSans.woff2
new file mode 100644
index 000000000..0964c7c46
--- /dev/null
+++ b/p/themes/fonts/OpenSans.woff2
Binary files differ
diff --git a/p/themes/fonts/openSans.woff b/p/themes/fonts/openSans.woff
deleted file mode 100644
index 55b25f867..000000000
--- a/p/themes/fonts/openSans.woff
+++ /dev/null
Binary files differ
diff --git a/p/api/greader.php b/p/api/greader.php
index b87fcc225..99304f4ec 100644
--- a/p/api/greader.php
+++ b/p/api/greader.php
@@ -20,7 +20,7 @@ Server-side API compatible with Google Reader API layer 2
* https://github.com/theoldreader/api
*/
-require('../../constants.php');
+require(__DIR__ . '/../../constants.php');
require(LIB_PATH . '/lib_rss.php'); //Includes class autoloader
$ORIGINAL_INPUT = file_get_contents('php://input', false, null, 0, 1048576);
@@ -78,10 +78,6 @@ class MyPDO extends Minz_ModelPdo {
}
}
-function logMe($text) {
- file_put_contents(join_path(USERS_PATH, '_', 'log_api.txt'), date('c') . "\t" . $text . "\n", FILE_APPEND);
-}
-
function debugInfo() {
if (function_exists('getallheaders')) {
$ALL_HEADERS = getallheaders();
@@ -107,16 +103,14 @@ function debugInfo() {
}
function badRequest() {
- logMe("badRequest()");
- logMe(debugInfo());
+ Minz_Log::warning('badRequest() ' . debugInfo(), API_LOG);
header('HTTP/1.1 400 Bad Request');
header('Content-Type: text/plain; charset=UTF-8');
die('Bad Request!');
}
function unauthorized() {
- logMe("unauthorized()");
- logMe(debugInfo());
+ Minz_Log::warning('unauthorized() ' . debugInfo(), API_LOG);
header('HTTP/1.1 401 Unauthorized');
header('Content-Type: text/plain; charset=UTF-8');
header('Google-Bad-Token: true');
@@ -124,22 +118,21 @@ function unauthorized() {
}
function notImplemented() {
- logMe("notImplemented()");
- logMe(debugInfo());
+ Minz_Log::warning('notImplemented() ' . debugInfo(), API_LOG);
header('HTTP/1.1 501 Not Implemented');
header('Content-Type: text/plain; charset=UTF-8');
die('Not Implemented!');
}
function serviceUnavailable() {
- logMe("serviceUnavailable()");
+ Minz_Log::warning('serviceUnavailable() ' . debugInfo(), API_LOG);
header('HTTP/1.1 503 Service Unavailable');
header('Content-Type: text/plain; charset=UTF-8');
die('Service Unavailable!');
}
function checkCompatibility() {
- logMe("checkCompatibility()");
+ Minz_Log::warning('checkCompatibility() ' . debugInfo(), API_LOG);
header('Content-Type: text/plain; charset=UTF-8');
if (PHP_INT_SIZE < 8 && !function_exists('gmp_init')) {
die('FAIL 64-bit or GMP extension!');
@@ -170,7 +163,7 @@ function authorizationToUser() {
if ($headerAuthX[1] === sha1(FreshRSS_Context::$system_conf->salt . $user . FreshRSS_Context::$user_conf->apiPasswordHash)) {
return $user;
} else {
- logMe('Invalid API authorisation for user ' . $user . ': ' . $headerAuthX[1]);
+ Minz_Log::warning('Invalid API authorisation for user ' . $user . ': ' . $headerAuthX[1], API_LOG);
Minz_Log::warning('Invalid API authorisation for user ' . $user . ': ' . $headerAuthX[1]);
unauthorized();
}
@@ -183,7 +176,6 @@ function authorizationToUser() {
}
function clientLogin($email, $pass) { //http://web.archive.org/web/20130604091042/http://undoc.in/clientLogin.html
- //logMe('clientLogin(' . $email . ")");
if (ctype_alnum($email)) {
if (!function_exists('password_verify')) {
include_once(LIB_PATH . '/password_compat.php');
@@ -215,7 +207,7 @@ function token($conf) {
//http://blog.martindoms.com/2009/08/15/using-the-google-reader-api-part-1/
//https://github.com/ericmann/gReader-Library/blob/master/greader.class.php
$user = Minz_Session::param('currentUser', '_');
//logMe('token('. $user . ")"); //TODO: Implement real token that expires
$token = str_pad(sha1(FreshRSS_Context::$system_conf->salt . $user . $conf->apiPasswordHash), 57, 'Z'); //Must have 57 characters
echo $token, "\n";
exit();
@@ -224,7 +216,6 @@ function token($conf) {
function checkToken($conf, $token) {
//http://code.google.com/p/google-reader-api/wiki/ActionToken
$user = Minz_Session::param('currentUser', '_');
- //logMe('checkToken(' . $token . ")");
if ($token === str_pad(sha1(FreshRSS_Context::$system_conf->salt . $user . $conf->apiPasswordHash), 57, 'Z')) {
return true;
}
@@ -232,7 +223,6 @@ function checkToken($conf, $token) {
}
function userInfo() { //https://github.com/theoldreader/api#user-info
- //logMe("userInfo()");
$user = Minz_Session::param('currentUser', '_');
exit(json_encode(array(
'userId' => $user,
@@ -243,7 +233,6 @@ function userInfo() { //https://github.com/theoldreader/api#user-info
}
function tagList() {
- //logMe("tagList()");
header('Content-Type: application/json; charset=UTF-8');
$pdo = new MyPDO();
@@ -268,7 +257,6 @@ function tagList() {
}
function subscriptionList() {
- //logMe("subscriptionList()");
header('Content-Type: application/json; charset=UTF-8');
$pdo = new MyPDO();
@@ -303,7 +291,6 @@ function subscriptionList() {
}
function subscriptionEdit($streamNames, $titles, $action, $add = '', $remove = '') {
- //logMe("subscriptionEdit()");
//https://github.com/mihaip/google-reader-api/blob/master/wiki/ApiSubscriptionEdit.wiki
switch ($action) {
case 'subscribe':
@@ -360,7 +347,7 @@ function subscriptionEdit($streamNames, $titles, $action, $add = '', $remove = '
$feed = FreshRSS_feed_Controller::addFeed($streamName, $title, $addCatId, $c_name, $http_auth);
continue;
} catch (Exception $e) {
- logMe("subscriptionEdit error subscribe: " . $e->getMessage());
+ Minz_Log::error('subscriptionEdit error subscribe: ' . $e->getMessage(), API_LOG);
}
}
badRequest();
@@ -389,7 +376,6 @@ function subscriptionEdit($streamNames, $titles, $action, $add = '', $remove = '
}
function quickadd($url) {
- //logMe("quickadd($url)");
try {
$feed = FreshRSS_feed_Controller::addFeed($url);
exit(json_encode(array(
@@ -397,7 +383,7 @@ function quickadd($url) {
'streamId' => $feed->id(),
)));
} catch (Exception $e) {
- logMe("subscriptionEdit error subscribe: " . $e->getMessage());
+ Minz_Log::error('quickadd error: ' . $e->getMessage(), API_LOG);
die(json_encode(array(
'numResults' => 0,
'error' => $e->getMessage(),
@@ -406,7 +392,6 @@ function quickadd($url) {
}
function unreadCount() { //http://blog.martindoms.com/2009/10/16/using-the-google-reader-api-part-2/#unread-count
- //logMe("unreadCount()");
header('Content-Type: application/json; charset=UTF-8');
$totalUnreads = 0;
@@ -453,7 +438,6 @@ function unreadCount() { //http://blog.martindoms.com/2009/10/16/using-the-googl
function streamContents($path, $include_target, $start_time, $count, $order, $exclude_target, $continuation) {
//http://code.google.com/p/pyrfeed/wiki/GoogleReaderAPI
//http://blog.martindoms.com/2009/10/16/using-the-google-reader-api-part-2/#feed
- //logMe("streamContents($path, $include_target, $start_time, $count, $order, $exclude_target, $continuation)");
header('Content-Type: application/json; charset=UTF-8');
$feedDAO = FreshRSS_Factory::createFeedDao();
@@ -517,7 +501,7 @@ function streamContents($path, $include_target, $start_time, $count, $order, $ex
'title' => $entry->title(),
'summary' => array('content' => $entry->content()),
'alternate' => array(
- array('href' => $entry->link()),
+ array('href' => htmlspecialchars_decode($entry->link(), ENT_QUOTES)),
),
'categories' => array(
'user/-/state/com.google/reading-list',
@@ -562,8 +546,6 @@ function streamContentsItemsIds($streamId, $start_time, $count, $order, $exclude
//http://code.google.com/p/google-reader-api/wiki/ApiStreamItemsIds
//http://code.google.com/p/pyrfeed/wiki/GoogleReaderAPI
//http://blog.martindoms.com/2009/10/16/using-the-google-reader-api-part-2/#feed
- //logMe("streamContentsItemsIds($streamId, $start_time, $count, $order, $exclude_target)");
-
$type = 'A';
$id = '';
if ($streamId === 'user/-/state/com.google/reading-list') {
@@ -610,8 +592,6 @@ function streamContentsItemsIds($streamId, $start_time, $count, $order, $exclude
}
function editTag($e_ids, $a, $r) {
- //logMe("editTag()");
-
foreach ($e_ids as $i => $e_id) {
$e_ids[$i] = hex2dec(basename($e_id)); //Strip prefix 'tag:google.com,2005:reader/item/'
}
@@ -645,7 +625,6 @@ function editTag($e_ids, $a, $r) {
}
function renameTag($s, $dest) {
- //logMe("renameTag()");
if ($s != '' && strpos($s, 'user/-/label/') === 0 &&
$dest != '' && strpos($dest, 'user/-/label/') === 0) {
$s = substr($s, 13);
@@ -661,7 +640,6 @@ function renameTag($s, $dest) {
}
function disableTag($s) {
- //logMe("disableTag($s)");
if ($s != '' && strpos($s, 'user/-/label/') === 0) {
$s = substr($s, 13);
$categoryDAO = new FreshRSS_CategoryDAO();
@@ -679,7 +657,6 @@ function disableTag($s) {
}
function markAllAsRead($streamId, $olderThanId) {
- //logMe("markAllAsRead($streamId, $olderThanId)");
$entryDAO = FreshRSS_Factory::createEntryDao();
if (strpos($streamId, 'feed/') === 0) {
$f_id = basename($streamId);
@@ -696,8 +673,8 @@ function markAllAsRead($streamId, $olderThanId) {
exit('OK');
}
-//logMe('----------------------------------------------------------------');
-//logMe(debugInfo());
+//Minz_Log::debug('----------------------------------------------------------------', API_LOG);
+//Minz_Log::debug(debugInfo(), API_LOG);
$pathInfo = empty($_SERVER['PATH_INFO']) ? '/Error' : urldecode($_SERVER['PATH_INFO']);
$pathInfos = explode('/', $pathInfo);
@@ -718,8 +695,6 @@ if ($user !== '') {
FreshRSS_Context::$user_conf = get_user_configuration($user);
}
-//logMe('User => ' . $user);
-
Minz_Session::_param('currentUser', $user);
if (count($pathInfos) < 3) {
@@ -215,7 +207,7 @@ function token($conf) {
//https://github.com/ericmann/gReader-Library/blob/master/greader.class.php
$user = Minz_Session::param('currentUser', '_');
- //logMe('token('. $user . ")"); //TODO: Implement real token that expires
+ //Minz_Log::debug('token('. $user . ')', API_LOG); //TODO: Implement real token that expires
$token = str_pad(sha1(FreshRSS_Context::$system_conf->salt . $user . $conf->apiPasswordHash), 57, 'Z'); //Must have 57 characters
echo $token, "\n";